==> dde-session-shell_5.3.0.45.orig.tar.xz: dde-session-shell-5.3.0.45/translations/dde-session-shell_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>ContentWidget</name>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="348"/>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat de computer kan worden afgesloten. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="349"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="354"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="358"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="362"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="366"/>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Klik op &apos;Annuleren&apos; en sluit de programma&apos;s.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="353"/>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat de computer kan worden herstart. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="357"/>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat de computer kan worden onderbroken. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="361"/>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat de computer in de slaapstand kan worden gezet. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="365"/>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat je kunt afmelden. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="382"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="423"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="445"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="593"/>
        <source>Shut down</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="385"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="425"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="448"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="596"/>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="388"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="599"/>
        <source>Suspend</source>
        <translation>Pauzestand</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="390"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="602"/>
        <source>Hibernate</source>
        <translation>Slaapstand</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="392"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="451"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="608"/>
        <source>Log out</source>
        <translation>Afmelden</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="446"/>
        <source>Are you sure you want to shut down?</source>
        <translation>Weet je zeker dat je de computer wilt uitschakelen?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="449"/>
        <source>Are you sure you want to reboot?</source>
        <translation>Weet je zeker dat je de computer opnieuw wilt opstarten?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="452"/>
        <source>Are you sure you want to log out?</source>
        <translation>Weet je zeker dat je wilt afmelden?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="605"/>
        <source>Lock</source>
        <translation>Vergrendelen</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="612"/>
        <source>Switch user</source>
        <translation>Andere gebruiker</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="617"/>
        <source>Switch system</source>
        <translation>Ander systeem</translation>
    </message>
</context>
<context>
    <name>GreeterWorkek</name>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="327"/>
        <source>Wrong Password</source>
        <translation>Het wachtwoord is onjuist</translation>
    </message>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="331"/>
        <source>The account or password is not correct. Please enter again.</source>
        <translation>Het account of wachtwoord is onjuist. Probeer het opnieuw.</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <location filename="../src/dde-shutdown/view/inhibitwarnview.cpp" line="90"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <location filename="../src/session-widgets/lockcontent.cpp" line="353"/>
        <source>Lock Screen</source>
        <translation>Scherm vergrendelen</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/lockcontent.cpp" line="357"/>
        <source>Failed to lock screen</source>
        <translation>Het scherm kan niet worden vegrendeld</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="229"/>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Vingerafdrukauthenticatie verlopen - voer je wachtwoord handmatig in</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="247"/>
        <source>Failed to match fingerprint</source>
        <translation>De vingerafdruk komt niet overeen</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="278"/>
        <source>Wrong Password</source>
        <translation>Het wachtwoord is onjuist</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="45"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="129"/>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Bovenstaande gebruikers zijn nog ingelogd. Niet-opgeslagen gegevens gaan verloren als gevolg van het afsluiten. Weet je zeker dat je wilt doorgaan?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="133"/>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Bovenstaande gebruikers zijn nog ingelogd. Niet-opgeslagen gegevens gaan verloren als gevolg van het opnieuw opstarten. Weet je zeker dat je wilt doorgaan?</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="29"/>
        <source>Shut down</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="30"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="101"/>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="31"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="108"/>
        <source>Suspend</source>
        <translation>Pauzestand</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="32"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="115"/>
        <source>Hibernate</source>
        <translation>Slaapstand</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <location filename="../src/dde-shutdown/view/systemmonitor.cpp" line="45"/>
        <source>Start system monitor</source>
        <translation>Systeemmonitor openen</translation>
    </message>
</context>
<context>
    <name>UserExpiredWidget</name>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="149"/>
        <source>Password expired, please change</source>
        <translation>Het wachtwoord is verlopen - wijzig het</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="153"/>
        <source>New password</source>
        <translation>Nieuw wachtwoord</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="163"/>
        <source>Repeat password</source>
        <translation>Wachtwoord herhalen</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="322"/>
        <source>Failed to change your password</source>
        <translation>Het wachtwoord kan niet worden gewijzigd</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="336"/>
        <source>Password too weak</source>
        <translation>Het wachtwoord is te zwak</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="344"/>
        <source>Please enter the new password</source>
        <translation>Voer het nieuwe wachtwoord in</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="350"/>
        <source>Please repeat the new password</source>
        <translation>Herhaal het nieuwe wachtwoord</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userexpiredwidget.cpp" line="356"/>
        <source>Passwords do not match</source>
        <translation>De wachtwoorden komen niet overeen</translation>
    </message>
</context>
<context>
    <name>UserLoginWidget</name>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="195"/>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="199"/>
        <source>Account</source>
        <translation>Account</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="241"/>
        <source>Please enter the account</source>
        <translation>Voer je accountnaam in</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="248"/>
        <source>Please enter the password</source>
        <translation>Voer je wachtwoord in</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/session-widgets/userloginwidget.cpp" line="328"/>
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Probeer het over %n minuut opnieuw</numerusform><numerusform>Probeer het over %n minuten opnieuw</numerusform></translation>
    </message>
</context>
</TS>

==> dde-session-shell_5.4.9.orig.tar.xz: dde-session-shell-5.4.9/translations/dde-session-shell_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>ContentWidget</name>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="357"/>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat de computer kan worden afgesloten. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="358"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="363"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="367"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="371"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="375"/>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Klik op &apos;Annuleren&apos; en sluit de programma&apos;s.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="362"/>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat de computer kan worden herstart. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="366"/>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat de computer kan worden onderbroken. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="370"/>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat de computer in de slaapstand kan worden gezet. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="374"/>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat je kunt afmelden. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="391"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="435"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="460"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="614"/>
        <source>Shut down</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="394"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="437"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="463"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="617"/>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="397"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="620"/>
        <source>Suspend</source>
        <translation>Pauzestand</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="399"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="623"/>
        <source>Hibernate</source>
        <translation>Slaapstand</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="401"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="466"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="629"/>
        <source>Log out</source>
        <translation>Afmelden</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="461"/>
        <source>Are you sure you want to shut down?</source>
        <translation>Weet je zeker dat je de computer wilt uitschakelen?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="464"/>
        <source>Are you sure you want to reboot?</source>
        <translation>Weet je zeker dat je de computer opnieuw wilt opstarten?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="467"/>
        <source>Are you sure you want to log out?</source>
        <translation>Weet je zeker dat je wilt afmelden?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="626"/>
        <source>Lock</source>
        <translation>Vergrendelen</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="632"/>
        <source>Switch user</source>
        <translation>Andere gebruiker</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="637"/>
        <source>Switch system</source>
        <translation>Ander systeem</translation>
    </message>
</context>
<context>
    <name>GreeterWorkek</name>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="329"/>
        <source>Wrong Password</source>
        <translation>Het wachtwoord is onjuist</translation>
    </message>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="333"/>
        <source>The account or password is not correct. Please enter again.</source>
        <translation>Het account of wachtwoord is onjuist. Probeer het opnieuw.</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <location filename="../src/dde-shutdown/view/inhibitwarnview.cpp" line="90"/>
        <location filename="../src/widgets/inhibitwarnview.cpp" line="90"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <location filename="../src/session-widgets/lockcontent.cpp" line="405"/>
        <source>Lock Screen</source>
        <translation>Scherm vergrendelen</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/lockcontent.cpp" line="409"/>
        <source>Failed to lock screen</source>
        <translation>Het scherm kan niet worden vegrendeld</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="291"/>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Vingerafdrukauthenticatie verlopen - voer je wachtwoord handmatig in</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="309"/>
        <source>Failed to match fingerprint</source>
        <translation>De vingerafdruk komt niet overeen</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="339"/>
        <source>Wrong Password</source>
        <translation>Het wachtwoord is onjuist</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="45"/>
        <location filename="../src/widgets/multiuserswarningview.cpp" line="45"/>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="130"/>
        <location filename="../src/widgets/multiuserswarningview.cpp" line="133"/>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Bovenstaande gebruikers zijn nog ingelogd. Niet-opgeslagen gegevens gaan verloren als gevolg van het afsluiten. Weet je zeker dat je wilt doorgaan?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="134"/>
        <location filename="../src/widgets/multiuserswarningview.cpp" line="137"/>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Bovenstaande gebruikers zijn nog ingelogd. Niet-opgeslagen gegevens gaan verloren als gevolg van het opnieuw opstarten. Weet je zeker dat je wilt doorgaan?</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="30"/>
        <source>Shut down</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="31"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="172"/>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="32"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="178"/>
        <source>Suspend</source>
        <translation>Pauzestand</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="33"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="184"/>
        <source>Hibernate</source>
        <translation>Slaapstand</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="190"/>
        <source>Lock</source>
        <translation>Vergrendelen</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="196"/>
        <source>Log out</source>
        <translation>Afmelden</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="202"/>
        <source>Switch user</source>
        <translation>Andere gebruiker</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="210"/>
        <source>Switch system</source>
        <translation>Ander systeem</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <location filename="../src/dde-shutdown/view/systemmonitor.cpp" line="45"/>
        <location filename="../src/widgets/systemmonitor.cpp" line="45"/>
        <source>Start system monitor</source>
        <translation>Systeemmonitor openen</translation>
    </message>
</context>
<context>
    <name>UserLoginWidget</name>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="193"/>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="197"/>
        <source>Account</source>
        <translation>Account</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="239"/>
        <source>Please enter the account</source>
        <translation>Voer je accountnaam in</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="246"/>
        <source>Please enter the password</source>
        <translation>Voer je wachtwoord in</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/session-widgets/userloginwidget.cpp" line="338"/>
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Probeer het over %n minuut opnieuw</numerusform><numerusform>Probeer het over %n minuten opnieuw</numerusform></translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="149"/>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat de computer kan worden afgesloten. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="150"/>
        <location filename="../src/widgets/warningcontent.cpp" line="155"/>
        <location filename="../src/widgets/warningcontent.cpp" line="159"/>
        <location filename="../src/widgets/warningcontent.cpp" line="163"/>
        <location filename="../src/widgets/warningcontent.cpp" line="167"/>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Klik op &apos;Annuleren&apos; en sluit de programma&apos;s.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="154"/>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat de computer kan worden herstart. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="158"/>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat de computer kan worden onderbroken. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="162"/>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat de computer in de slaapstand kan worden gezet. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="166"/>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat je kunt afmelden. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="182"/>
        <location filename="../src/widgets/warningcontent.cpp" line="235"/>
        <location filename="../src/widgets/warningcontent.cpp" line="267"/>
        <source>Shut down</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="185"/>
        <location filename="../src/widgets/warningcontent.cpp" line="237"/>
        <location filename="../src/widgets/warningcontent.cpp" line="270"/>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="188"/>
        <source>Suspend</source>
        <translation>Pauzestand</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="190"/>
        <source>Hibernate</source>
        <translation>Slaapstand</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="192"/>
        <location filename="../src/widgets/warningcontent.cpp" line="273"/>
        <source>Log out</source>
        <translation>Afmelden</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="268"/>
        <source>Are you sure you want to shut down?</source>
        <translation>Weet je zeker dat je de computer wilt uitschakelen?</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="271"/>
        <source>Are you sure you want to reboot?</source>
        <translation>Weet je zeker dat je de computer opnieuw wilt opstarten?</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="274"/>
        <source>Are you sure you want to log out?</source>
        <translation>Weet je zeker dat je wilt afmelden?</translation>
    </message>
</context>
</TS>
